@@ -754,3 +754,17 @@ warn_and_return <- function(..., call. = TRUE) {
   warning(cond)
   rlang::eval_bare(quote(return(invisible())), parent.frame())
 }
+
+# paste collapse and
+pc_and <-  function (..., sep = "")  {
+  x <- paste(..., sep = sep, collapse = NULL)
+  lx <- length(x)
+  if (lx == 0L)
+    ""
+  else if (lx == 1L)
+    x
+  else if (lx == 2L)
+    paste0(x, collapse = " and ")
+  else
+    paste0(paste0(x[-lx], collapse = ", "), ", and ", x[lx])
+}
