@@ -1,3 +1,6 @@
+
+#define RCPP_NO_MODULES
+#define RCPP_NO_SUGAR
 #include <Rcpp.h>
 using namespace Rcpp;
 
@@ -15,5 +18,3 @@ int write_stderr(std::string text) {
   REprintf("%s", text.c_str());
   return text.length();
 }
-
-
